@@ -1,3 +1,4 @@
+import re
 import dataclasses  # type: ignore
 from dataclasses import InitVar
 from typing import Any, Dict, Optional, Union
@@ -67,13 +68,13 @@ class BaseClient:
         this_func -> get/post/put -> caller
         """
         caller_filename = inspect.stack()[2][1]  # 1 is for filename
-        if "/infer/" in caller_filename:
+        if re.search(r'[/\\]infer[/\\]', caller_filename):
             return self.infer_url + suffix
-        if "/feedback/" in caller_filename:
+        if re.search(r"[/\\]feedback[/\\]", caller_filename):
             return self.infer_url + suffix
-        elif "/label/" in caller_filename:
+        elif re.search(r"[/\\]label[/\\]", caller_filename):
             return self.label_url + suffix
-        elif "/auth/" in caller_filename:
+        elif re.search(r"[/\\]auth[/\\]", caller_filename):
             return self.label_url + suffix
         else:
             called_func = inspect.stack()[1][3]  #  BaseClient.{get/put/post}
